<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package ecowp
 */

if ( ! function_exists( 'matt_post_thumbnail' ) ) :
	/**
	 * Displays an optional post thumbnail.
	 *
	 * Wraps the post thumbnail in an anchor element on index views, or a div
	 * element when on single views.
	 */
	function matt_post_thumbnail() {
		if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
			return;
		}

		if ( is_singular() ) :
			?>

			<div class="post-thumbnail">
				<?php the_post_thumbnail(); ?>
			</div><!-- .post-thumbnail -->

		<?php else : ?>

			<a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
				<?php
					the_post_thumbnail(
						'post-thumbnail',
						array(
							'alt' => the_title_attribute(
								array(
									'echo' => false,
								)
							),
						)
					);
				?>
			</a>

			<?php
		endif; // End is_singular().
	}
endif;

if (!function_exists('matt_entry_footer')):
		/**
		 * Prints HTML with meta information for the categories, tags and comments.
		 * Footer entry meta is displayed differently in archives and single posts.
		 *
		 * @since Twenty Twenty-One 1.0
		 *
		 * @return void
		 */
		function matt_entry_footer(): void {

			// Early exit if not a post.
			if ( 'post' !== get_post_type() ) {
				return;
			}

			// Hide meta information on pages.
			if ( ! is_single() ) {

				echo '<p class="post-meta-comments">';

				$nb_com = get_comments_number();
				if ($nb_com > 0) {
                    echo '<a href="' . get_comments_link() . '">';
					printf(_n('%s Comment', '%s Comment', $nb_com ), $nb_com);
                    echo '</a> - ';
				}

				echo '<a href="' . get_comments_link() . '">'. __('Leave a Comment') .'</a></p>';

			}
		}
endif;

if (!function_exists('matt_entry_header')):
	/**
	 * Prints HTML with meta information for the categories.
	 *
	 * @return void
	 */
	function matt_entry_header(): void {

		// Early exit if not a post.
		if ( 'post' !== get_post_type() ) {
			return;
		}

		// Hide meta information on pages.
		if ( ! is_single() ) {
			if ( has_category() ) {
				/* translators: Used between list items, there is a space after the comma. */
				$categories_list = get_the_category_list( ' • ' );
				if ( $categories_list ) {
					printf(
					/* translators: %s: List of categories. */
						'<p class="cat-links">' . esc_html__( '%s', 'matt' ) . ' </p>',
						$categories_list // phpcs:ignore WordPress.Security.EscapeOutput
					);
				}
			}
			// Posted on.
			matt_posted_on();
		}
	}
endif;

if (!function_exists('matt_posted_on')):
    /**
     * Prints a post date
     * Must be in the loop
     */
    function matt_posted_on() {
        $time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

        $time_string = sprintf(
            $time_string,
            esc_attr( get_the_date( DATE_W3C ) ),
            esc_html( get_the_date() )
        );
        echo '<p class="posted-on">';
        printf(
        /* translators: %s: Publish date. */
            esc_html__( '%s', 'matt' ),
            $time_string // phpcs:ignore WordPress.Security.EscapeOutput
        );
        echo '</span>';
    }
endif;